////////////////////////////////////////////////////////////////
// タイマーガジェット
//   Copyright (C) 2008 - 2012 AAOh inc.
////////////////////////////////////////////////////////////////

/**
 * @fileOverview タイマーガジェット
 * @author       $Author: fujishiro $
 */

(function () {
/**
 * timer。
 *
 * @namespace
 */
timer = {
}
})();

(function () {
/**
 * Control。
 *
 * @constructor
 */
timer.Control = aaoh.kaze.Gadget.extend(
	aaoh.sora.ControlEx, function() {
	// Application名。
	this.APP_NAME    = 'timer';
	this.APP_VERSION = '2.6.0';

	// Windowサイズ。
	this.WINDOW_ONDOCK_WIDTH         = 130 +  0;
	this.WINDOW_ONDOCK_HEIGHT        = 100 + 12;
	this.WINDOW_UNDOCK_WIDTH         = this.WINDOW_ONDOCK_WIDTH;
	this.WINDOW_UNDOCK_HEIGHT        = this.WINDOW_ONDOCK_HEIGHT;
	this.WINDOW_ONDOCK_MOBILE_WIDTH  = this.WINDOW_ONDOCK_WIDTH;
	this.WINDOW_ONDOCK_MOBILE_HEIGHT = this.WINDOW_ONDOCK_HEIGHT;
	this.WINDOW_UNDOCK_MOBILE_WIDTH  = this.WINDOW_ONDOCK_MOBILE_WIDTH;
	this.WINDOW_UNDOCK_MOBILE_HEIGHT = this.WINDOW_ONDOCK_MOBILE_HEIGHT;
	this.WINDOW_OPTION_WIDTH         = 250 +  0;
	this.WINDOW_OPTION_HEIGHT        = 320 + 12;
	this.WINDOW_OPTION_MOBILE_WIDTH  = 230 +  0;
	this.WINDOW_OPTION_MOBILE_HEIGHT = 200 + 12;

	// デフォルト値
	this.INTERVAL       = 100; // 計測インターバル(msec)

	this.FLG_START      = 1; // 計測状態フラグ
	this.FLG_STOP       = 2;
	this.FLG_SUSPEND    = 3;

	this.MODE_COUNTDOWN = '1'; // 計測モード
	this.MODE_COUNTUP   = '2';

	this.DEFAULT_ALERT_MSG       = this.locale.getString('ALERT_MSG');
	this.DEFAULT_SOUND_FILE      = 'alert.mp3';
	if (aaoh.kaze.Type.isSidebar()) {
		this.DEFAULT_SOUND_FILE    = 'alert.wav';

	} else if (aaoh.kaze.Type.isYahoo()) {
		this.DEFAULT_SOUND_FILE    = 'Resources/alert.mp3';
	}
	this.DEFAULT_REPEAT_INTERVAL = 3000; // msec

	// sound
	this.sound = new aaoh.kaze.Sound();

	// copyright
	this.LST_IMG_NM.push('imgCopilot');
	this.LST_LNK_NM.push('lnkCopilot');
	this.LST_URL['imgCopilot'] = 'http://copilot.jp/';
	this.LST_URL['lnkCopilot'] = 'http://copilot.jp/';
})
	/**
	 * 設定用計測時間の取得。
	 *
	 * @param  {Number} hour 時
	 * @param  {Number} min  分
	 * @param  {Number} sec  秒
	 * @return {Number}      計測時間(msec)
	 */
	timer.Control.prototype.
	getTime = function(hour, min, sec) {
		var time = (hour * 60 * 60 * 1000) + (min * 60 * 1000) + (sec * 1000);
		return time;
	}

	/**
	 * 表示用計測時間の取得。
	 *
	 * @param  {Number} time 計測時間(msec)
	 * @return {String} hour, min, sec, msecの配列
	 */
	timer.Control.prototype.
	getShowTime = function(time) {
		var hourNum = parseInt(time / (60 * 60 * 1000), 10);
		var minNum  = parseInt(
			(time - (hourNum * 60 * 60 * 1000)) / (60 * 1000), 10
		);
		var srcNum  = parseInt((time % (60 * 1000)) / 1000, 10);
		var msecNum = parseInt(time % 1000, 10);

		// 時間の編集
		var hour = String(hourNum);
		var min  = String(minNum);
		var sec  = String(srcNum);
		var msec = String(msecNum);
		if (min.length < 2) {
			min = '0' + min;
		}
		if (sec.length < 2) {
			sec = '0' + sec;
		}
		if (msec.length < 2) {
			msec = '0';
		} else {
			msec = msec.substring(0, 1);
		}

		var timeList = new Array();
		timeList[0] = hour;
		timeList[1] = min;
		timeList[2] = sec;
		timeList[3] = msec;

		return timeList;
	}
})();

(function () {
/**
 * Model。
 *
 * @constructor
 */
timer.Model = aaoh.kaze.Gadget.extend(
	aaoh.sora.ModelEx, function() {
	this.data.type        = '1';
	this.data.mode        = '1';
	this.data.numTime1    = 180000; // 3min
	this.data.numTime2    = 60000;  // 1min
	this.data.numTime3    = 30000;  // 30sec
	this.data.isAlert     = true;
	this.data.isAlertDef  = true;
	this.data.alertMsg    = '';
	this.data.isSound     = true;
	this.data.isSoundDef  = true;
	this.data.soundFile   = '';
	this.data.numSoundVol = 50;
});
	/**
	 * 設定情報の読込み(iGoogle)。
	 */
	timer.Model.prototype.
	readDataForIGoogle = function() {
		var type        = aaoh.sora.App.control.storage.readString('type');
		var mode        = aaoh.sora.App.control.storage.readString('mode');
		//var numTime1    = aaoh.sora.App.control.storage.readString('numTime1');
		//var numTime2    = aaoh.sora.App.control.storage.readString('numTime2');
		//var numTime3    = aaoh.sora.App.control.storage.readString('numTime3');
		var numTime1Hour = aaoh.sora.App.control.storage.readString('numTime1Hour');
		var numTime1Min  = aaoh.sora.App.control.storage.readString('numTime1Min');
		var numTime1Sec  = aaoh.sora.App.control.storage.readString('numTime1Sec');
		var numTime2Hour = aaoh.sora.App.control.storage.readString('numTime2Hour');
		var numTime2Min  = aaoh.sora.App.control.storage.readString('numTime2Min');
		var numTime2Sec  = aaoh.sora.App.control.storage.readString('numTime2Sec');
		var numTime3Hour = aaoh.sora.App.control.storage.readString('numTime3Hour');
		var numTime3Min  = aaoh.sora.App.control.storage.readString('numTime3Min');
		var numTime3Sec  = aaoh.sora.App.control.storage.readString('numTime3Sec');
		var isAlert     = aaoh.sora.App.control.storage.readString('isAlert');
		var isAlertDef  = aaoh.sora.App.control.storage.readString('isAlertDef');
		var alertMsg    = aaoh.sora.App.control.storage.readString('alertMsg');
		var isSound     = aaoh.sora.App.control.storage.readString('isSound');
		var isSoundDef  = aaoh.sora.App.control.storage.readString('isSoundDef');
		var soundFile   = aaoh.sora.App.control.storage.readString('soundFile');
		var numSoundVol = aaoh.sora.App.control.storage.readString('numSoundVol');

		var numTime1
			= aaoh.sora.App.control.getTime(numTime1Hour, numTime1Min, numTime1Sec);
		var numTime2
			= aaoh.sora.App.control.getTime(numTime2Hour, numTime2Min, numTime2Sec);
		var numTime3
			= aaoh.sora.App.control.getTime(numTime3Hour, numTime3Min, numTime3Sec);

		if (type != null) {
			this.data.type = type;
		}
		if (mode != null) {
			this.data.mode = mode;
		}
		if (numTime1 > 0) {
			this.data.numTime1 = numTime1;
		}
		if (numTime2 > 0) {
			this.data.numTime2 = numTime2;
		}
		if (numTime3 > 0) {
			this.data.numTime3 = numTime3;
		}
		this.data.isAlert    = isAlert;
		this.data.isAlertDef = isAlertDef;
		if (alertMsg != null) {
			this.data.alertMsg = alertMsg;
		}
		this.data.isSound    = isSound;
		this.data.isSoundDef = isSoundDef;
		if (soundFile != null) {
			this.data.soundFile = soundFile;
		}
		if (numSoundVol > 0) {
			this.data.numSoundVol = numSoundVol;
		}
	}

	/**
	 * 設定情報の書込み(iGoogle)。
	 */
	timer.Model.prototype.
	writeDataForIGoogle = function() {
		aaoh.sora.App.control.storage.writeString(
			'type', this.data.type
		);
		aaoh.sora.App.control.storage.writeString(
			'mode', this.data.mode
		);
		aaoh.sora.App.control.storage.writeString(
			'numTime1', this.data.numTime1
		);
		aaoh.sora.App.control.storage.writeString(
			'numTime2', this.data.numTime2
		);
		aaoh.sora.App.control.storage.writeString(
			'numTime3', this.data.numTime3
		);
		aaoh.sora.App.control.storage.writeString(
			'isAlert', this.data.isAlert
		);
		aaoh.sora.App.control.storage.writeString(
			'isAlertDef', this.data.isAlertDef
		);
		aaoh.sora.App.control.storage.writeString(
			'alertMsg', this.data.alertMsg
		);
		aaoh.sora.App.control.storage.writeString(
			'isSound', this.data.isSound
		);
		aaoh.sora.App.control.storage.writeString(
			'isSoundDef', this.data.isSoundDef
		);
		aaoh.sora.App.control.storage.writeString(
			'soundFile', this.data.soundFile
		);
		aaoh.sora.App.control.storage.writeString(
			'numSoundVol', this.data.numSoundVol
		);
	}
})();

(function () {
/**
 * App。
 *
 * @namespace
 */
aaoh.sora.App = {
	control: new timer.Control(),
	model:   new timer.Model(),
	main:    null,
	option:  null,

	/**
	 * 初期化。
	 *
	 * @param {String} target 初期化するターゲット
	 */
	init: function(target) {
		if (
			target != null && target == aaoh.sora.App.control.MAIN_NM
		) {
			aaoh.sora.App.main   = new timer.Main();
			aaoh.sora.App.option = null;

		} else if (
			target != null && target == aaoh.sora.App.control.OPTION_NM
		) {
			aaoh.sora.App.main   = null;
			aaoh.sora.App.option = new timer.Option();

		} else {
			aaoh.sora.App.main   = new timer.Main();
			aaoh.sora.App.option = new timer.Option();
		}

		// バージョンチェックを行う
		aaoh.sora.App.control.FLG_UPDATE = true;

		aaoh.sora.App.control.init();
	}
}
})();
